==> divraster_1.0.3.tar.gz: divraster/README.md <==

# divraster

<!-- badges: start -->
[![CRAN-status](https://www.r-pkg.org/badges/version/divraster)](https://cran.r-project.org/package=divraster)
[![R-CMD-check](https://github.com/flaviomoc/divraster/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/flaviomoc/divraster/actions/workflows/R-CMD-check.yaml)
[![](http://cranlogs.r-pkg.org/badges/grand-total/divraster?color=green)](https://cran.r-project.org/package=divraster)
[![](http://cranlogs.r-pkg.org/badges/divraster?color=green)](https://cran.r-project.org/package=divraster)
<!-- badges: end -->

Alpha and beta calculations using rasters for taxonomic (TD), functional (FD), and phylogenetic (PD) dimensions. Spatial and temporal beta diversity can be partitioned into replacement and richness difference components. Functions to calculate standardized effect size for functional and phylogenetic alpha diversity and the average traits are available.

### Installation

The CRAN version of `divraster` can be installed using:

``` r
install.packages("divraster")
```

The development version of `divraster` can be installed from Github using:

``` r
devtools::install_github("flaviomoc/divraster")
```

### `divraster` basics

Basic information about `divraster` can be found at the [package's webpage](https://flaviomoc.github.io/divraster/) or in the vignette:

``` r
vignette("divraster-vignette")
```

### Citation

- If you use this R package, please cite in your publications:

Mota FMM, Heming NM, Alves-Ferreira G (2023). divraster: an R package to calculate taxonomic, functional and phylogenetic diversity from rasters. <https://CRAN.R-project.org/package=divraster>.

- For more information:

``` r
citation("divraster")
```

### Issues

If you have any question or find any bug, let us know through the topic [Issues](https://github.com/flaviomoc/divraster/issues).

==> divraster_1.2.3.tar.gz: divraster/README.md <==

# divraster

<!-- badges: start -->
[![CRAN-status](https://www.r-pkg.org/badges/version/divraster)](https://cran.r-project.org/package=divraster)
[![R-CMD-check](https://github.com/flaviomoc/divraster/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/flaviomoc/divraster/actions/workflows/R-CMD-check.yaml)
[![](http://cranlogs.r-pkg.org/badges/grand-total/divraster?color=green)](https://cran.r-project.org/package=divraster)
[![](http://cranlogs.r-pkg.org/badges/divraster?color=green)](https://cran.r-project.org/package=divraster)
<!-- badges: end -->

Alpha and beta calculations using rasters for taxonomic (TD), functional (FD), and phylogenetic (PD) dimensions. Spatial and temporal beta diversity can be partitioned into replacement and richness difference components. Functions to calculate standardized effect size for functional and phylogenetic alpha diversity and the average traits are available.

### Installation

The CRAN version of `divraster` can be installed using:

``` r
install.packages("divraster")
```

The development version of `divraster` can be installed from Github using:

``` r
devtools::install_github("flaviomoc/divraster")
```

### `divraster` basics

Basic information about `divraster` can be found at the [package's webpage](https://flaviomoc.github.io/divraster/) or in the vignette:

``` r
vignette("divraster-vignette")
```

### Citation

- If you use this R package, please cite in your publications:

Mota FMM, Alves-Ferreira G, Talora DC, Heming NM (2023). divraster: an R package to calculate taxonomic, functional and phylogenetic diversity from rasters. -- Ecography, e06905.

- For more information:

``` r
citation("divraster")
```

### Issues

If you have any question or find any bug, let us know through the topic [Issues](https://github.com/flaviomoc/divraster/issues).
